import { ClippingRenderContext, EdgeRenderingMode, HorizontalAlignment, LineJoin, OxyColor, OxyImage, OxyRect, OxySize, type ScreenPoint, VerticalAlignment } from 'oxyplot-js';
import { jsPDF } from 'jspdf';
export declare class PdfRenderContext extends ClippingRenderContext {
    private readonly _pdf;
    private readonly ctx;
    private readonly _textMeasurer;
    private readonly styleConverter;
    private readonly _ctxInitStyles;
    constructor(orientation?: 'p' | 'portrait' | 'l' | 'landscape');
    getPdf(): jsPDF;
    drawImage(source: OxyImage, srcX: number, srcY: number, srcWidth: number, srcHeight: number, destX: number, destY: number, destWidth: number, destHeight: number, opacity: number, interpolate: boolean): Promise<void>;
    /**
     * Draws line segments.
     * @param points The points.
     * @param stroke The stroke color.
     * @param thickness The thickness.
     * @param edgeRenderingMode The edge rendering mode.
     * @param dashArray The dash array.
     * @param lineJoin The line join.
     */
    drawLineSegments(points: ScreenPoint[], stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode, dashArray?: number[], lineJoin?: LineJoin): Promise<void>;
    drawLine(points: ScreenPoint[], stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode, dashArray?: number[], lineJoin?: LineJoin): Promise<void>;
    /**
     * Draws a polygon.
     * @param points The points.
     * @param fill The fill color.
     * @param stroke The stroke color.
     * @param thickness The thickness.
     * @param edgeRenderingMode The edge rendering mode.
     * @param dashArray The dash array.
     * @param lineJoin The line join.
     */
    drawPolygon(points: ScreenPoint[], fill: OxyColor, stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode, dashArray?: number[], lineJoin?: LineJoin): Promise<void>;
    /**
     * Draws multiple polygons.
     * @param polygons The polygons.
     * @param fill The fill color.
     * @param stroke The stroke color.
     * @param thickness The thickness.
     * @param edgeRenderingMode The edge rendering mode.
     * @param dashArray The dash array.
     * @param lineJoin The line join.
     */
    drawPolygons(polygons: ScreenPoint[][], fill: OxyColor, stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode, dashArray: number[] | undefined, lineJoin: LineJoin): Promise<void>;
    /**
     * Draws the text.
     * @param p The position of the text.
     * @param text The text.
     * @param fill The fill color.
     * @param fontFamily The font family.
     * @param fontSize Size of the font.
     * @param fontWeight The font weight.
     * @param rotation The rotation angle.
     * @param horizontalAlignment The horizontal alignment.
     * @param verticalAlignment The vertical alignment.
     * @param maxSize The maximum size of the text.
     */
    drawText(p: ScreenPoint, text: string, fill: OxyColor, fontFamily: string | undefined, fontSize: number, fontWeight?: number, rotation?: number, horizontalAlignment?: HorizontalAlignment, verticalAlignment?: VerticalAlignment, maxSize?: OxySize): Promise<void>;
    measureText(text: string, fontFamily: string | undefined, fontSize: number, fontWeight: number): OxySize;
    protected setClip(rect: OxyRect): void;
    protected resetClip(): void;
    private applyLineStyle;
    private clearStyles;
    private applyPolygonStyle;
    private applyTextStyle;
    private drawPoints;
}
//# sourceMappingURL=PdfRenderContext.d.ts.map